@@ -101,6 +101,7 @@ static const char *No_visible = N_("No visible messages.");
 #define UNREAD(h) mutt_thread_contains_unread (Context, h)
 
 extern const char *ReleaseDate;
+extern size_t UngetCount;
 
 void index_make_entry (char *s, size_t l, MUTTMENU *menu, int num)
 {
@@ -508,6 +509,7 @@ int mutt_index_menu (void)
     }
 
 #ifdef USE_IMAP
+    imap_keepalive ();
     imap_disallow_reopen (Context);
 #endif
 
@@ -632,6 +634,40 @@ int mutt_index_menu (void)
       else if (option (OPTAUTOTAG) && Context && Context->tagged)
 	tag = 1;
 
+      if (op == OP_TAG_PREFIX_COND)
+      {
+	if (!Context)
+	{
+	  mutt_error _("No mailbox is open.");
+	  continue;
+	}
+
+	if (!Context->tagged)
+	{
+	  event_t tmp;
+	  while(UngetCount>0)
+	  {
+	    tmp=mutt_getch();
+	    if(tmp.op==OP_END_COND)break;
+	  }
+	  mutt_message  _("Nothing to do.");
+	  continue;
+	}
+	tag = 1;
+
+	/* give visual indication that the next command is a tag- command */
+	mvaddstr (LINES - 1, 0, "tag-");
+	clrtoeol ();
+
+	/* get the real command */
+	if ((op = km_dokey (MENU_MAIN)) == OP_TAG_PREFIX)
+	{
+	  /* abort tag sequence */
+	  CLEARLINE (LINES-1);
+	  continue;
+	}
+      }
+
       mutt_clear_error ();
     }
     else
@@ -817,6 +853,7 @@ CHECK_IMAP_ACL(IMAP_ACL_DELETE);
 	  menu->redraw = REDRAW_INDEX | REDRAW_STATUS;
 	  if ((Sort & SORT_MASK) == SORT_THREADS)
 	    mutt_draw_tree (Context);
+	  menu->redraw = REDRAW_FULL;
 	}
 	break;	  
 
@@ -940,7 +977,8 @@ CHECK_IMAP_ACL(IMAP_ACL_DELETE);
 
 #ifdef USE_IMAP
       case OP_MAIN_IMAP_FETCH:
-      	ImapLastCheck = 0;
+	if (Context->magic == M_IMAP)
+	  imap_check_mailbox (Context, &index_hint, 1);
         break;
 #endif
       
@@ -1048,6 +1086,12 @@ CHECK_IMAP_ACL(IMAP_ACL_DELETE);
 
         mutt_sleep (0);
       
+	/* Set CurrentMenu to MENU_MAIN before executing any folder
+	 * hooks so that all the index menu functions are available to
+	 * the exec command.
+	 */
+
+	CurrentMenu = MENU_MAIN;
 	mutt_folder_hook (buf);
 
 	if ((Context = mx_open_mailbox (buf, 
@@ -1873,8 +1917,9 @@ CHECK_IMAP_ACL(IMAP_ACL_SEEN);
 	{
 	  if (option (OPTRESOLVE))
 	  {
-	    if ((menu->oldcurrent = ci_next_undeleted (menu->current)) == -1)
-	      menu->oldcurrent = menu->current;
+	    if ((menu->current = (op == OP_MAIN_READ_THREAD ? 
+				  mutt_next_thread (CURHDR) : mutt_next_subthread (CURHDR))) == -1)
+	      menu->current = menu->oldcurrent;
 	  }
 	  menu->redraw = REDRAW_INDEX | REDRAW_STATUS;
 	}
@@ -2019,6 +2064,9 @@ CHECK_IMAP_ACL(IMAP_ACL_DELETE);
 	menu->redraw = REDRAW_FULL;
 	break;
 
+      case OP_END_COND:
+	break;
+
       case OP_WHAT_KEY:
 	mutt_what_key();
 	break;
