@@ -1401,7 +1401,9 @@ static void maildir_update_tables (CONTEXT *ctx, int *index_hint)
     if (ctx->hdrs[i]->active)
       ctx->hdrs[i]->index = j++;
   }
+
   mx_update_tables (ctx, 0);
+  mutt_clear_threads (ctx);
 }
 
 static void maildir_update_flags (CONTEXT *ctx, HEADER *o, HEADER *n)
@@ -1517,7 +1519,7 @@ int maildir_check_mailbox (CONTEXT * ctx, int *index_hint)
     ctx->hdrs[i]->active = 0;
     maildir_canon_filename (buf, ctx->hdrs[i]->path, sizeof (buf));
     p = hash_find (fnames, buf);
-    if (p)
+    if (p && p->h)
     {
       /* message already exists, merge flags */
       ctx->hdrs[i]->active = 1;
