@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>
+ * Copyright (C) 1996-2000 Michael R. Elkins <me@mutt.org>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -13,7 +13,7 @@
  * 
  *     You should have received a copy of the GNU General Public License
  *     along with this program; if not, write to the Free Software
- *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
  */ 
 
 /* dynamic internal flags */
@@ -29,6 +29,7 @@
 #define M_PAGER_MARKER		(1<<6)	/* use markers if option is set */
 #define M_PAGER_RETWINCH	(1<<7)	/* need reformatting on SIGWINCH */
 #define M_PAGER_MESSAGE		(M_SHOWCOLOR | M_PAGER_MARKER)
+#define M_PAGER_ATTACHMENT	(1<<8)
 
 #define M_DISPLAYFLAGS	(M_SHOW | M_PAGER_NSKIP | M_PAGER_MARKER)
 
