@@ -692,10 +692,10 @@ void _smime_getkeys (char *mailbox)
   }
 
   snprintf (SmimeKeyToUse, sizeof (SmimeKeyToUse), "%s/%s", 
-	    NONULL (SmimeKeys), SmimeDefaultKey);
+	    NONULL (SmimeKeys), NONULL (SmimeDefaultKey));
   
   snprintf (SmimeCertToUse, sizeof (SmimeCertToUse), "%s/%s",
-	    NONULL (SmimeCertificates), SmimeDefaultKey);
+	    NONULL (SmimeCertificates), NONULL (SmimeDefaultKey));
 }
 
 void smime_getkeys (ENVELOPE *env)
@@ -1837,9 +1837,10 @@ static BODY *smime_handle_entity (BODY *m, STATE *s, FILE *outFile)
       m->goodsig = 1;
     FREE (&line);
   }
-  else {
+  else 
+  {
     m->goodsig = p->goodsig;
-    m->badsig = p->badsig;
+    m->badsig  = p->badsig;
   }
   fclose (smimeerr);
 
