@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000 Thomas Roessler <roessler@guug.de>
+ * Copyright (C) 2000 Thomas Roessler <roessler@does-not-exist.org>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -50,7 +50,9 @@ static void url_pct_decode (char *s)
   for (d = s; *s; s++)
   {
     if (*s == '%' && s[1] && s[2] &&
-	hexval (s[1]) >= 0 && hexval(s[2]) >= 0)
+	isxdigit ((unsigned char) s[1]) &&
+        isxdigit ((unsigned char) s[2]) &&
+	hexval (s[1]) >= 0 && hexval (s[2]) >= 0)
     {
       *d++ = (hexval (s[1]) << 4) | (hexval (s[2]));
       s += 2;
@@ -67,7 +69,7 @@ url_scheme_t url_check_scheme (const char *s)
   char *t;
   int i;
   
-  if (!(t = strchr (s, ':')))
+  if (!s || !(t = strchr (s, ':')))
     return U_UNKNOWN;
   if ((t - s) + 1 >= sizeof (sbuf))
     return U_UNKNOWN;
@@ -211,7 +213,9 @@ int url_parse_mailto (ENVELOPE *e, char **body, const char *src)
   if (!(t = strchr (src, ':')))
     return -1;
   
-  tmp = safe_strdup (t + 1);
+  if ((tmp = safe_strdup (t + 1)) == NULL)
+    return -1;
+
   if ((headers = strchr (tmp, '?')))
     *headers++ = '\0';
 
@@ -244,7 +248,7 @@ int url_parse_mailto (ENVELOPE *e, char **body, const char *src)
     }
   }
   
-  safe_free ((void **) &tmp);
+  FREE (&tmp);
   return 0;
 }
 
